@@ -24,6 +24,7 @@ position = [
     "php",
     "ruby",
     "elixir",
+    "ember",
     "julia",
     "dart",
     "dotnet",
@@ -132,6 +133,14 @@ prefix.text = "via"
 version.enable = false
 version.micro.enable = true
 
+[ember]
+symbol = "\\ue71b"
+color = "red"
+prefix.color = "negative"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = false
+
 [erlang]
 symbol = "\\ue7b1"
 color = "red"
@@ -243,7 +252,7 @@ version.enable = false
 version.micro.enable = true
 
 [ocaml]
-symbol = "?"
+symbol = "ocaml"
 color = "yellow"
 prefix.color = "negative"
 prefix.text = "via"
@@ -323,6 +332,14 @@ prefix.text = "via"
 version.enable = false
 version.micro.enable = true
 
+[r]
+symbol = "R"
+color = "blue"
+prefix.color = "negative"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
 [scala]
 symbol = "\\ue737"
 color = "red"
